import react from 'react';
import { useState, useEffect } from 'react';
import { Map, Marker, ZoomControl } from 'pigeon-maps';
import { Geolocation } from '@awesome-cordova-plugins/geolocation';
import LiveOverlay from './live-overlay';

const LiveMap: react.FC = () => {
  const initialCenter: [number, number] = [44.73574, 6.18981];
  const initialZoom: number = 15;
  const [center, setCenter] = useState(initialCenter);
  const [position, setPosition] = useState(initialCenter);
  const [zoom, setZoom] = useState(initialZoom);

  const emptyTrack: any = {
    type: 'Feature',
    geometry: {
      type: 'LineString',
      coordinates: [],
    },
    properties: { foo: 'track' },
  };

  let [track, setTrack] = useState(emptyTrack);

  useEffect(() => {
    Geolocation.getCurrentPosition().then((position) => {
      setCenter([position.coords.latitude, position.coords.longitude]);
      setPosition([position.coords.latitude, position.coords.longitude]);
      track.geometry.coordinates = [
        [position.coords.longitude, position.coords.latitude],
      ];
      setTrack(track);
    });
  }, [track]);

  return (
    <Map
      center={center}
      zoom={zoom}
      onBoundsChanged={({ center, zoom }) => {
        setCenter(center);
        setZoom(zoom);
      }}
      animate={true}
    >
      <ZoomControl />
      <Marker width={20} anchor={position} />
      {track.geometry.coordinates.length !== 0 && (
        <LiveOverlay
          mapState={undefined}
          latLngToPixel={undefined}
          track={track}
        />
      )}
    </Map>
  );
};

export default LiveMap;
